@@ -21,9 +21,14 @@ from superannotate_schemas.schemas.base import INVALID_DICT_MESSAGE
 from superannotate_schemas.schemas.base import NotEmptyStr
 from superannotate_schemas.schemas.base import StrictNumber
 from superannotate_schemas.schemas.base import Tag
+from superannotate_schemas.schemas.base import BaseInstanceTag
 from superannotate_schemas.schemas.enums import VectorAnnotationTypeEnum
 
 
+class InstanceTag(BaseInstanceTag):
+    class_name: NotEmptyStr
+
+
 class Attribute(BaseAttribute):
     name: NotEmptyStr
     group_name: NotEmptyStr = Field(alias="groupName")
@@ -115,12 +120,13 @@ ANNOTATION_TYPES = {
     VectorAnnotationTypeEnum.POLYLINE: PolyLine,
     VectorAnnotationTypeEnum.ELLIPSE: Ellipse,
     VectorAnnotationTypeEnum.RBBOX: RotatedBox,
+    VectorAnnotationTypeEnum.TAG: InstanceTag,
 }
 
 
 class AnnotationInstance(BaseModel):
     __root__: Union[
-        Template, Cuboid, Point, PolyLine, Polygon, Bbox, Ellipse, RotatedBox
+        Template, Cuboid, Point, PolyLine, Polygon, Bbox, Ellipse, RotatedBox, InstanceTag
     ]
 
     @classmethod
